aboutsummaryrefslogtreecommitdiff
path: root/src/parsertab.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/parsertab.c')
-rw-r--r--src/parsertab.c26
1 files changed, 13 insertions, 13 deletions
diff --git a/src/parsertab.c b/src/parsertab.c
index f876401..a3236d5 100644
--- a/src/parsertab.c
+++ b/src/parsertab.c
@@ -1,4 +1,4 @@
/* grecs - Gray's Extensible Configuration System
Copyright (C) 2007-2016 Sergey Poznyakoff
Grecs is free software; you can redistribute it and/or modify it
@@ -20,32 +20,32 @@
#include <stdlib.h>
#include <strings.h>
#include <errno.h>
-#include "grecs.h"
+#include "argot.h"
static struct parser_tab {
const char *name;
- grecs_parser_t parser;
+ argot_parser_t parser;
} parser_tab[] = {
- { "GRECS", grecs_grecs_parser },
- { "PATH", grecs_path_parser },
+ { "ARGOT", argot_argot_parser },
+ { "PATH", argot_path_parser },
#ifdef ENABLE_META1_PARSER
- { "META1", grecs_meta1_parser },
+ { "META1", argot_meta1_parser },
#endif
#ifdef ENABLE_BIND_PARSER
- { "BIND", grecs_bind_parser },
+ { "BIND", argot_bind_parser },
#endif
#ifdef ENABLE_DHCPD_PARSER
- { "DHCPD", grecs_dhcpd_parser },
- { "DHCP", grecs_dhcpd_parser },
+ { "DHCPD", argot_dhcpd_parser },
+ { "DHCP", argot_dhcpd_parser },
#endif
#ifdef ENABLE_GIT_PARSER
- { "GIT", grecs_git_parser },
+ { "GIT", argot_git_parser },
#endif
{ NULL }
};
int
-grecs_enumerate_parsers(int (*fun)(const char *, grecs_parser_t, void *),
+argot_enumerate_parsers(int (*fun)(const char *, argot_parser_t, void *),
void *data)
{
struct parser_tab *pt;
@@ -56,8 +56,8 @@ grecs_enumerate_parsers(int (*fun)(const char *, grecs_parser_t, void *),
return rc;
}
-grecs_parser_t
-grecs_get_parser_by_type(const char *type)
+argot_parser_t
+argot_get_parser_by_type(const char *type)
{
struct parser_tab *pt;
@@ -1,4 +1,4 @@
-/* grecs - Gray's Extensible Configuration System
+/* argot - Gray's Extensible Configuration System
Copyright (C) 2007-2016 Sergey Poznyakoff
Grecs is free software; you can redistribute it and/or modify it

Return to:

Send suggestions and report system problems to the System administrator.